@@ -3,20 +3,7 @@ import pandas as pd
 import requests
 from bs4 import BeautifulSoup
 
-
-def find_between(s, first, last):
-    try:
-        try:
-            start = s.index(first) + len(first)
-            end = s.index(last, start)
-            return s[start:end]
-        except ValueError:
-            start = s.index(first) + len(first)
-            return s[start:]
-
-    except BaseException as e:
-        print(e, first, last)
-        return 'NA'
+from JATA.Helpers import find_between
 
 
 class CJH_Archives:
